@@ -50,6 +50,7 @@ def all_adducts_iter(DB,adductsAll,ionisation,db):
 
 
 def MS1_ann_iter(df,allAdds,ppm,me,ppmthr,ppmunk,ratiounk,pRTNone,pRTout,sigmaln,k):
+    Charge= df.iloc[k,7]
     mm= df.iloc[k,2]
     rtm=df.iloc[k,3]
     ppms = ((mm-allAdds.iloc[:,5])/allAdds.iloc[:,5])*(10**6) 
@@ -109,8 +110,13 @@ def MS1_ann_iter(df,allAdds,ppm,me,ppmthr,ppmunk,ratiounk,pRTNone,pRTout,sigmaln
                         pMs.append(stats.norm(0, ppm/2).pdf(ppmk)/stats.norm(0, ppm/2).pdf(0))
                         pIs.append(stats.lognorm(scale=ISt.iloc[ps,1],s=sigmaln).pdf(ISm.iloc[ps,1])/stats.lognorm(scale=ISt.iloc[ps,1],s=sigmaln).pdf(math.exp(ISt.iloc[ps,1]-(sigmaln)**2) ))
 
+                    if ch!=Charge:
+                        pMs= [(stats.norm(0, ppm).pdf(2*ppm)/stats.norm(0, ppm).pdf(0))/1000]*len(ISm.index)
+                        pIs= [(stats.lognorm(scale=ISt.iloc[0,1],s=sigmaln).pdf(ISt.iloc[0,1]+ratiounk*ISt.iloc[0,1])/stats.lognorm(scale=ISt.iloc[0,1],s=sigmaln).pdf(math.exp(ISt.iloc[0,1]-(sigmaln)**2)))/1000]*len(ISm.index)
                     pisoM.append(sum(pMs))
                     pisoI.append(sum(pIs))
+                    
+                        
             ###adding scores for unknown
             pisoM.append(sum([stats.norm(0, ppm).pdf(2*ppm)/stats.norm(0, ppm).pdf(0)]*len(ISm.index)))
             pisoI.append(sum([stats.lognorm(scale=ISt.iloc[0,1],s=sigmaln).pdf(ISt.iloc[0,1]+ratiounk*ISt.iloc[0,1])/stats.lognorm(scale=ISt.iloc[0,1],s=sigmaln).pdf(math.exp(ISt.iloc[0,1]-(sigmaln)**2))]*len(ISm.index)))    
@@ -150,6 +156,7 @@ def MS1_ann_iter(df,allAdds,ppm,me,ppmthr,ppmunk,ratiounk,pRTNone,pRTout,sigmaln
 
 
 def MSMS_ann_iter1(df,dfMS2,allAdds,DBMS2,ppm,me,ratiosd,ppmthr,ppmunk,ratiounk,pRTNone,pRTout,mzdCS,ppmCS,CSunk,sigmaln,k):
+    Charge= df.iloc[k,7]
     mm= df.iloc[k,2]
     rtm=df.iloc[k,3]
     ppms = ((mm-allAdds.iloc[:,5])/allAdds.iloc[:,5])*(10**6) 
@@ -208,7 +215,10 @@ def MSMS_ann_iter1(df,dfMS2,allAdds,DBMS2,ppm,me,ratiosd,ppmthr,ppmunk,ratiounk,
                         ppmk =((ISt.iloc[ps,0]-ISm.iloc[ps,0])/ISt.iloc[ps,0])*(10**6)
                         pMs.append(stats.norm(0, ppm/2).pdf(ppmk)/stats.norm(0, ppm/2).pdf(0))
                         pIs.append(stats.lognorm(scale=ISt.iloc[ps,1],s=sigmaln).pdf(ISm.iloc[ps,1])/stats.lognorm(scale=ISt.iloc[ps,1],s=sigmaln).pdf(math.exp(ISt.iloc[ps,1]-(sigmaln)**2) ))
-
+                    
+                    if ch!=Charge:
+                        pMs= [(stats.norm(0, ppm).pdf(2*ppm)/stats.norm(0, ppm).pdf(0))/1000]*len(ISm.index)
+                        pIs= [(stats.lognorm(scale=ISt.iloc[0,1],s=sigmaln).pdf(ISt.iloc[0,1]+ratiounk*ISt.iloc[0,1])/stats.lognorm(scale=ISt.iloc[0,1],s=sigmaln).pdf(math.exp(ISt.iloc[0,1]-(sigmaln)**2)))/1000]*len(ISm.index)
                     pisoM.append(sum(pMs))
                     pisoI.append(sum(pIs))
             ###adding scores for unknown
@@ -286,6 +296,7 @@ def MSMS_ann_iter1(df,dfMS2,allAdds,DBMS2,ppm,me,ratiosd,ppmthr,ppmunk,ratiounk,
 
 
 def MSMS_ann_iter2(df,dfMS2,allAdds,DBMS2,ppm,me,ratiosd,ppmthr,ppmunk,ratiounk,pRTNone,pRTout,mzdCS,ppmCS,CSunk,sigmaln,k):
+    Charge= df.iloc[k,7]
     mm= df.iloc[k,2]
     rtm=df.iloc[k,3]
     ppms = ((mm-allAdds.iloc[:,5])/allAdds.iloc[:,5])*(10**6) 
@@ -344,6 +355,9 @@ def MSMS_ann_iter2(df,dfMS2,allAdds,DBMS2,ppm,me,ratiosd,ppmthr,ppmunk,ratiounk,
                         ppmk =((ISt.iloc[ps,0]-ISm.iloc[ps,0])/ISt.iloc[ps,0])*(10**6)
                         pMs.append(stats.norm(0, ppm/2).pdf(ppmk)/stats.norm(0, ppm/2).pdf(0))
                         pIs.append(stats.lognorm(scale=ISt.iloc[ps,1],s=sigmaln).pdf(ISm.iloc[ps,1])/stats.lognorm(scale=ISt.iloc[ps,1],s=sigmaln).pdf(math.exp(ISt.iloc[ps,1]-(sigmaln)**2) ))
+                    if ch!=Charge:
+                        pMs= [(stats.norm(0, ppm).pdf(2*ppm)/stats.norm(0, ppm).pdf(0))/1000]*len(ISm.index)
+                        pIs= [(stats.lognorm(scale=ISt.iloc[0,1],s=sigmaln).pdf(ISt.iloc[0,1]+ratiounk*ISt.iloc[0,1])/stats.lognorm(scale=ISt.iloc[0,1],s=sigmaln).pdf(math.exp(ISt.iloc[0,1]-(sigmaln)**2)))/1000]*len(ISm.index)
 
                     pisoM.append(sum(pMs))
                     pisoI.append(sum(pIs))
@@ -518,18 +532,20 @@ def gibbs_sampler_bio_add_iter(indk,ks,rids,annotations,Bio,ca_id,ca,delta_bio,d
         p_bio = [0]*len(tmp.index) ### initialize the p_add vector
         p_add = [0]*len(tmp.index) ### initialize the p_add vector
         ca_id2=[] # contains the the current annotation ids for the masses with the same the relation id
+        ca_id3=ca_id.copy() # contains the the current annotation
+        del ca_id3[i] # without the annotation for the mass considered 
         for r in range(0,len(rids)):
             if rids[r]==rid and r!=k:
                 ca_id2.append(ca_id[r]) ## 
-
-        #padd = [ca_id2.count(x) for x in idcps]
+   
         for cp in range(0,len(p_add)): ###populating p_add by counting add connections
             idcp = tmp.iloc[cp,0] ### annotation considered for this position of p_add
             if idcp!='Unknown':
                 p_add[cp] = ca_id2.count(idcp)## count the number of add connections
-            idcp_list = [idcp]*len(ca_id2)
-            A = list(zip(idcp_list,ca_id2))+list(zip(ca_id2,idcp_list))
-            p_bio[cp] = len(set.intersection(set(Bio),set(A)))
+            idcp_list = [idcp]*len(ca_id3)
+            A = list(zip(idcp_list,ca_id3))+list(zip(ca_id3,idcp_list))
+            p_bio[cp] = len(set.intersection(set(Bio),set(A)))    
+       
         p_add=[x+delta_add for x in p_add] ###computing the actual p_add 1/2
         p_add=[x/sum(p_add) for x in p_add] ###computing the actual p_add 2/2
         p_bio=[x+delta_bio for x in p_bio] ###computing the actual p_bio 1/2
